Caddy.Application (Caddy v2.3.1)
View SourceOTP Application for Caddy reverse proxy management.
Starts the main Caddy supervisor tree when the application starts. Note: Only starts in non-test environments (see mix.exs).
OTP Application for Caddy reverse proxy management.
Starts the main Caddy supervisor tree when the application starts. Note: Only starts in non-test environments (see mix.exs).