Caddy.Server.Embedded (Caddy v2.3.1)
View SourceEmbedded Caddy Server.
Manages the Caddy binary process directly using Erlang ports.
This is used when config :caddy, mode: :embedded (default).
The server:
- Spawns and monitors the Caddy binary process
- Handles process output and logs
- Manages process lifecycle (start/stop/restart)
- Cleans up on termination
Won't start if Caddy binary is not found or not executable.
Can be restarted via Caddy.restart_server() after setting the binary path.
Summary
Functions
Returns a specification to start this module under a supervisor.
Get Caddyfile content of the current running server
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
@spec get_caddyfile() :: binary()
Get Caddyfile content of the current running server